@@ -3,7 +3,7 @@ import logging
 import re
 from typing import Dict, List, Optional, Set
 
-from gpt_index.data_structs.data_structs import Node
+from gpt_index.data_structs.node_v2 import Node
 from gpt_index.utils import globals_helper, truncate_text
 from gpt_index.vector_stores.types import VectorStoreQueryResult
 
