@@ -2,9 +2,7 @@
 
 # TODO: move LLMPredictor to this folder
 from gpt_index.llm_predictor.base import LLMPredictor
+from gpt_index.llm_predictor.stable_lm import StableLMPredictor
 from gpt_index.llm_predictor.structured import StructuredLLMPredictor
 
-__all__ = [
-    "LLMPredictor",
-    "StructuredLLMPredictor",
-]
+__all__ = ["LLMPredictor", "StructuredLLMPredictor", "StableLMPredictor"]
