@@ -12,6 +12,7 @@ definition of a Document - the bare minimum is a `text` property.
 
 from gpt_index.readers.chatgpt_plugin import ChatGPTRetrievalPluginReader
 from gpt_index.readers.chroma import ChromaReader
+from gpt_index.readers.deeplake import DeepLakeReader
 from gpt_index.readers.discord_reader import DiscordReader
 from gpt_index.readers.elasticsearch import ElasticsearchReader
 from gpt_index.readers.faiss import FaissReader
@@ -61,6 +62,7 @@ __all__ = [
     "QdrantReader",
     "MilvusReader",
     "ChromaReader",
+    "DeepLakeReader",
     "FaissReader",
     "Document",
     "StringIterableReader",
