@@ -1,6 +1,7 @@
 """Node postprocessor tests."""
 
 import pytest
+from gpt_index.docstore.simple_docstore import SimpleDocumentStore
 
 from gpt_index.indices.query.schema import QueryBundle
 from gpt_index.prompts.prompts import Prompt, SimpleInputPrompt
@@ -12,8 +13,9 @@ from gpt_index.indices.postprocessor.node import (
 from gpt_index.indices.postprocessor.node_recency import (
     FixedRecencyPostprocessor,
     EmbeddingRecencyPostprocessor,
+    TimeWeightedPostprocessor,
 )
-from gpt_index.docstore import DocumentStore
+from gpt_index.indices.query.embedding_utils import SimilarityTracker
 from gpt_index.llm_predictor import LLMPredictor
 from unittest.mock import patch
 from gpt_index.embeddings.openai import OpenAIEmbedding
@@ -71,7 +73,7 @@ def test_forward_back_processor() -> None:
                 {DocumentRelationship.NEXT: nodes[i + 1].get_doc_id()},
             )
 
-    docstore = DocumentStore()
+    docstore = SimpleDocumentStore()
     docstore.add_documents(nodes)
 
     # check for a single node
@@ -231,7 +233,6 @@ def test_embedding_recency_postprocessor(
     result_nodes = postprocessor.postprocess_nodes(
         nodes, extra_info={"query_bundle": query_bundle}
     )
-    print(result_nodes)
     assert len(result_nodes) == 4
     assert result_nodes[0].get_text() == "This is a test v2."
     assert cast(Dict, result_nodes[0].node_info)["date"] == "2020-01-04"
@@ -240,3 +241,72 @@ def test_embedding_recency_postprocessor(
     assert cast(Dict, result_nodes[1].node_info)["date"] == "2020-01-03"
     assert result_nodes[2].get_text() == "This is a test."
     assert cast(Dict, result_nodes[2].node_info)["date"] == "2020-01-02"
+
+
+@patch.object(LLMPredictor, "predict", side_effect=mock_recency_predict)
+@patch.object(LLMPredictor, "__init__", return_value=None)
+@patch.object(
+    OpenAIEmbedding, "_get_text_embedding", side_effect=mock_get_text_embedding
+)
+@patch.object(
+    OpenAIEmbedding, "_get_text_embeddings", side_effect=mock_get_text_embeddings
+)
+@patch.object(
+    OpenAIEmbedding, "get_query_embedding", side_effect=mock_get_query_embedding
+)
+def test_time_weighted_postprocessor(
+    _mock_query_embed: Any,
+    _mock_texts: Any,
+    _mock_text: Any,
+    _mock_init: Any,
+    _mock_predict: Any,
+) -> None:
+    """Test time weighted processor."""
+
+    key = "__last_accessed__"
+    # try in extra_info
+    nodes = [
+        Node("Hello world.", doc_id="1", node_info={key: 0}),
+        Node("This is a test.", doc_id="2", node_info={key: 1}),
+        Node("This is another test.", doc_id="3", node_info={key: 2}),
+        Node("This is a test v2.", doc_id="4", node_info={key: 3}),
+    ]
+
+    # high time decay
+    similarity_tracker = SimilarityTracker()
+    postprocessor = TimeWeightedPostprocessor(
+        top_k=1, time_decay=0.99999, time_access_refresh=True, now=4.0
+    )
+    result_nodes = postprocessor.postprocess_nodes(
+        nodes, extra_info={"similarity_tracker": similarity_tracker}
+    )
+
+    result_nodes_with_score = similarity_tracker.get_zipped_nodes(result_nodes)
+    assert len(result_nodes_with_score) == 1
+    assert result_nodes_with_score[0].node.get_text() == "This is a test v2."
+    assert cast(Dict, nodes[0].node_info)[key] == 0
+    assert cast(Dict, nodes[3].node_info)[key] != 3
+
+    # low time decay
+    # artifically make earlier nodes more relevant
+    # therefore postprocessor should still rank earlier nodes higher
+    nodes = [
+        Node("Hello world.", doc_id="1", node_info={key: 0}),
+        Node("This is a test.", doc_id="2", node_info={key: 1}),
+        Node("This is another test.", doc_id="3", node_info={key: 2}),
+        Node("This is a test v2.", doc_id="4", node_info={key: 3}),
+    ]
+    similarity_tracker = SimilarityTracker()
+    for idx, node in enumerate(nodes):
+        similarity_tracker.add(node, -float(idx))
+    postprocessor = TimeWeightedPostprocessor(
+        top_k=1, time_decay=0.000000000002, time_access_refresh=True, now=4.0
+    )
+    result_nodes = postprocessor.postprocess_nodes(
+        nodes, extra_info={"similarity_tracker": similarity_tracker}
+    )
+    result_nodes_with_score = similarity_tracker.get_zipped_nodes(result_nodes)
+    assert len(result_nodes_with_score) == 1
+    assert result_nodes_with_score[0].node.get_text() == "Hello world."
+    assert cast(Dict, nodes[0].node_info)[key] != 0
+    assert cast(Dict, nodes[3].node_info)[key] == 3
